package com.utic.center.utic.traf.server.dao.mapper.utic;

import com.utic.center.utic.traf.server.dto.LinkTrafCenterDto;
import com.utic.center.utic.traf.server.dto.TrafPrcsTimeDto;
import com.utic.center.utic.traf.server.dto.ViewTextDto;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface UticTrafficMapper {

    ViewTextDto findNextMonth();
    ViewTextDto findTrafficCenterViewDdl();

    TrafPrcsTimeDto findOneTrafPrcsTime();
    int truncateTrafficLoc();
    int insertCenterRecv(@Param("centerId") String centerId, @Param("infoType") String infoType, @Param("seq") Integer seq, @Param("dataCnt") Integer dataCnt);

    int truncateTrafficCenter(@Param("tableName") String tableName);
    int disableIndexes(@Param("tableName") String tableName, @Param("index") String index);
    int disablePrimaryKey(@Param("tableName") String tableName);
    int rebuildIndexes(@Param("tableName") String tableName, @Param("index") String index);
    int enablePrimaryKey(@Param("tableName") String tableName);
    int insertTrafficCenter(@Param("tableName") String tableName, @Param("obj") LinkTrafCenterDto obj);
    int swapTrafficCenterView(@Param("sourceTable") String sourceTable);

}
